## Running inside a container

Molecule is built into a Docker image by the [Ansible Creator Execution
Environment](https://github.com/ansible/creator-ee) project.

Any questions or bugs related to use of Molecule from within a container
should be addressed by the Ansible Creator Execution Environment
project.
